@@ -11,7 +11,7 @@ fractions, random, collections and datetime, should work on any python platform
 where these are available.
 
 INSTALLATION:
-Put the folder where Python can see it.
+pip install usefulpython
 
 RELEASE NOTES:
 0
@@ -25,6 +25,21 @@ RELEASE NOTES:
   Version 0.1.0:
    Addition of more programs that contain more functions. Addition of 
    usefulpy IDE. Improvement of functions.
+  Version 0.1.1:
+   Restructured to be supported as a package
+  Version 0.1.2:
+   A couple bugfixes
+  Version 0.1.3:
+   Fixed error in folder structure.
+  Version 0.1.4:
+   More bugfixes!
+  Version 0.1.5:
+   Succesfully restructured to be a package. Also bugfixes.
+ 0.2
+  Version 0.2.0
+   Mathfunc class capabilities expanded with a simple algebraic simplifier
+   system. Math sections improved for faster and better capabilities.
+   Newer, faster prime sieve.
 
 SECTIONS:
 validation
@@ -44,7 +59,7 @@ IDE
 
 ### INFO ###
 __author__ = 'Austin Garcia'
-__version__ = '0.1.0'
+__version__ = '0.1.5'
 __package__ = 'usefulpy'
 
 ### IMPORT ###
